@@ -241,8 +241,7 @@ class CortxJupyter(ContentsManager):
 # The documentation suggests that leading slashes in the
 # path are not present, but they are, mostly
 def _key(context, path):
-    print(path)
-    print(path.lstrip('/'))
+    print(context.prefix + path.lstrip('/'))
     return context.prefix + path.lstrip('/')
     # return context.prefix + path
 
